@@ -7,17 +7,26 @@ from restclients_core.exceptions import DataFailureException
 import json
 
 
-def get_resource(url, headers):
+def get_resource(url, headers={}):
+    headers["Connection"] = "keep-alive"
+
+    response = Catalyst_DAO().getURL(url, headers)
+
+    if response.status != 200:
+        raise DataFailureException(url, response.status, response.data)
+
+    return response
+
+
+def get_json_resource(url, headers={}):
     """
     Issue a GET request with the given url and headers,
     and return a response in json format.
     :returns: http response with content in json
     """
     headers["Accept"] = "application/json"
-    response = Catalyst_DAO().getURL(url, headers)
 
-    if response.status != 200:
-        raise DataFailureException(url, response.status, response.data)
+    response = get_resource(url, headers)
 
     try:
         return json.loads(response.data)
