@@ -9,3 +9,8 @@ Contains custom exceptions used by the catalyst rest client.
 class InvalidGradebookID(Exception):
     """Exception for invalid gradebook id."""
     pass
+
+
+class InvalidSurveyID(Exception):
+    """Exception for invalid survey id."""
+    pass
